@@ -1,7 +1,7 @@
 use crate::prelude::*;
 use crate::{enums::*, widget::Widget};
 
-#[derive(Clone)]
+#[derive(Debug, Clone)]
 pub struct Choice {
     inner: Widget,
 }
@@ -21,12 +21,7 @@ impl WidgetBase for Choice {
         crate::group::Group::current_attach(&inner);
         Self { inner }
     }
-    fn default_fill() -> Self {
-        let s = Self::default();
-        s.inner.set_style(Style::Width, "100%");
-        s.inner.set_style(Style::Height, "100%");
-        s
-    }
+
     unsafe fn from_widget(widget: &Widget) -> Self {
         Self {
             inner: widget.clone(),
@@ -39,7 +34,7 @@ impl WidgetBase for Choice {
 
 impl WidgetExt for Choice {}
 
-#[derive(Clone)]
+#[derive(Debug, Clone)]
 pub struct NavBar {
     inner: Widget,
 }
@@ -77,12 +72,7 @@ impl WidgetBase for NavBar {
         crate::group::Group::current_attach(&inner);
         Self { inner }
     }
-    fn default_fill() -> Self {
-        let s = Self::default();
-        s.inner.set_style(Style::Width, "100%");
-        s.inner.set_style(Style::Height, "100%");
-        s
-    }
+
     unsafe fn from_widget(widget: &Widget) -> Self {
         Self {
             inner: widget.clone(),
@@ -96,7 +86,7 @@ impl WidgetBase for NavBar {
 impl WidgetExt for NavBar {}
 
 
-#[derive(Clone)]
+#[derive(Debug, Clone)]
 pub struct MenuBar {
     inner: Widget,
 }
@@ -140,12 +130,7 @@ impl WidgetBase for MenuBar {
         crate::group::Group::current_attach(&inner);
         Self { inner }
     }
-    fn default_fill() -> Self {
-        let s = Self::default();
-        s.inner.set_style(Style::Width, "100%");
-        s.inner.set_style(Style::Height, "100%");
-        s
-    }
+
     unsafe fn from_widget(widget: &Widget) -> Self {
         Self {
             inner: widget.clone(),
